@@ -34,10 +34,26 @@ class Color:
     def __repr__(self):
         return f"Color({self.r},{self.g},{self.b}, alpha={self.a})"
 
+    @property
+    def lightness(self):
+        return hls(self)[1]
+
+    @property
+    def hue(self):
+        return hls(self)[0]
+
+    @property
+    def value(self):
+        return hls(self)[2]
+
+    @property
+    def saturation(self):
+        return hsv(self)[2]
+
     # #### `Color.saturated`
 
     def saturated(self, saturation: float) -> Color:
-        h, _, v = self.hsv()
+        h, _, v = hsv(self)
         return hsv(h, saturation, v, alpha=self.a)
 
     # #### `Color.lit`
@@ -57,19 +73,39 @@ class Color:
     def transparent(self, alpha: float) -> Color:
         return Color(self.r, self.g, self.b, alpha=alpha)
 
+    # #### `Color.lighter`
+
+    def lighter(self, alpha: float) -> Color:
+        return self.towards(Colors.White, alpha, space="rgb")
+
+    # #### `Color.darker`
+
+    def darker(self, alpha: float) -> Color:
+        return self.towards(Colors.Black, alpha, space="rgb")
+
+    # #### `Color.brighter`
+
+    def brighter(self, alpha: float) -> Color:
+        return self.towards(self.saturated(1.0), alpha, space="hsv")
+
+    # #### `Color.dimmer`
+
+    def dimmer(self, alpha: float) -> Color:
+        return self.towards(self.saturated(0.0), alpha, space="hsv")
+
     # #### `Color.redshift`
 
-    def redshift(self, percent: float, *, space="hls") -> Color:
+    def redshift(self, percent: float) -> Color:
         _, l, s = hls(self)
         target = hls(0, l, s)
-        return self.towards(target, percent, space=space)
+        return self.towards(target, percent, space="rgb")
 
     # #### `Color.blueshift`
 
-    def blueshift(self, percent: float, *, space="hls") -> Color:
+    def blueshift(self, percent: float) -> Color:
         _, l, s = hls(self)
         target = hls(1, l, s)
-        return self.towards(target, percent, space=space)
+        return self.towards(target, percent, space="rgb")
 
     # #### `Color.towards`
 
@@ -111,7 +147,7 @@ def rgb(*args, **kwargs):
         return color.r / 255, color.g / 255, color.b / 255
     else:
         r, g, b = args
-        alpha = kwargs.pop("alpha")
+        alpha = kwargs.pop("alpha", 1.0)
 
         return Color(int(r * 255), int(g * 255), int(b * 255), alpha=alpha)
 
@@ -136,7 +172,7 @@ def hsv(*args, **kwargs):
     else:
         h, s, v = args
         r, g, b = colorsys.hsv_to_rgb(h, s, v)
-        alpha = kwargs.pop("alpha")
+        alpha = kwargs.pop("alpha", 1.0)
 
         return rgb(r, g, b, alpha=alpha)
 
