@@ -13,7 +13,7 @@ from typing import List, Tuple, Union, TYPE_CHECKING
 from .selector import Selector
 from .units import Unit, fr, ms, pc, minmax, rem, repeat, sec
 from .types import GridSize, GridTemplate, FontWeight
-from .color import Color, gray
+from .color import Color, Colors, gray
 from .helpers import style_method
 
 # This trick is necessary to annotate the `Style.animation` method
@@ -202,6 +202,30 @@ class Style:
     def background(self, color: Color) -> Style:
         self.rule("background-color", color)
 
+    @style_method
+    def shadow(
+        self,
+        color: Color = None,
+        *,
+        x: Unit = 0,
+        y: Unit = 0,
+        blur: Unit = 0,
+        spread: Unit = 0,
+    ) -> Style:
+        if color is None:
+            self.rule("box-shadow", "none")
+            return self
+
+        rule = [
+            str(Unit.infer(x)),
+            str(Unit.infer(y)),
+            str(Unit.infer(blur)),
+            str(Unit.infer(spread)),
+            str(color),
+        ]
+
+        self.rule("box-shadow", " ".join(rule))
+
     # #### `Style.border`
 
     @style_method
@@ -268,7 +292,7 @@ class Style:
     # #### `Style.size`
 
     @style_method
-    def size(self, width:Unit, height:Unit) -> Style:
+    def size(self, width: Unit, height: Unit) -> Style:
         self.width(width)
         self.height(height)
 
@@ -619,9 +643,9 @@ class Style:
         timing: str = "linear",
         direction: str = "normal",
     ) -> Style:
-        self._animation_configs.append((
-            animation.name, Unit.infer(duration, sec, ms), timing, iter, direction
-        ))
+        self._animation_configs.append(
+            (animation.name, Unit.infer(duration, sec, ms), timing, iter, direction)
+        )
 
         self._animations.add(animation)
 
@@ -634,9 +658,9 @@ class Style:
         for name, duration, timing, iter, direction in self._animation_configs:
             names.append(name)
             durations.append(str(duration))
-            timings.append(timing)
-            iterations.append(iter)
-            directions.append(direction)
+            timings.append(str(timing))
+            iterations.append(str(iter))
+            directions.append(str(direction))
 
         self.rule("animation-name", ", ".join(names))
         self.rule("animation-duration", ", ".join(durations))
