@@ -26,7 +26,7 @@ from .media import MediaQuery
 
 class StyleSheet:
     def __init__(
-        self, *styles: Style, normalize: bool = True, base: Style = None
+        self, *styles: Style, normalize: bool = False, base: Style = None
     ) -> None:
         """Initializes a new StyleSheet, optionally with a set of initial styles
         and a base style for inheritance.
@@ -53,7 +53,7 @@ class StyleSheet:
         if normalize:
             self._preamble = open(Path(__file__).parent / "normalize.css").read()
         else:
-            self._preamble = None
+            self._preamble = ""
 
     # ### Rendering methods
 
@@ -117,7 +117,7 @@ class StyleSheet:
 
         # Generate all animations, but each one only once.
 
-        for animation in animations:
+        for animation in sorted(animations, key=lambda a: a.name):
             fp.write(animation.css())
             fp.write("\n\n")
 
@@ -141,7 +141,7 @@ class StyleSheet:
 
     def _write_preamble(self, fp):
         fp.write("/* Made with violetear */\n")
-        fp.write(f"/* Autogenerated on {datetime.datetime.now()} */\n\n")
+        fp.write("/* This file is autogenerated. Do not modify. */\n\n")
 
         fp.write(self._preamble)
 
